@@ -6,23 +6,31 @@ from nonebot.adapters.onebot.v11.permission import (
     PRIVATE_FRIEND,
 )
 from pathlib import Path
+import ast
+import platform
 try:
     import ujson as json
 except:
     import json
     
-file_format = (".vpk",".zip",".7z")
+file_format = (".vpk",".zip",".7z",'rar')
 # 权限
 
+
+CHECK_FILE:int = 0
+
+
 reMaster = SUPERUSER | GROUP_OWNER 
 Master = SUPERUSER | GROUP_ADMIN | GROUP_OWNER 
 ADMINISTRATOR = SUPERUSER | GROUP_ADMIN | GROUP_OWNER | PRIVATE_FRIEND
 # file 填写求生服务器所在路径
 FONT_ORIGIN_PATH = Path(__file__).parent / 'data/L4D2/font.ttf'
+
 try:
-    l4_file: str = nonebot.get_driver().config.l4_file
+    l4_file: list[str] = nonebot.get_driver().config.l4_file
 except:
-    l4_file: str = '/home/ubuntu/l4d2/coop'
+    l4_file: list[str] = ['/home/ubuntu/l4d2']
+l4_file = ast.literal_eval(l4_file)
 
 try:
     l4_image: bool = nonebot.get_driver().config.l4_image
@@ -40,36 +48,54 @@ except:
     l4_font: str = str(FONT_ORIGIN_PATH)
      
 try:
-    l4_host: str = nonebot.get_driver().config.l4_host
+    l4_host: list[str] = nonebot.get_driver().config.l4_host
 except:
-    l4_host: str = '127.0.0.1'
+    l4_host: list[str] = ['127.0.0.1']
+l4_host = ast.literal_eval(l4_host)
     
 try:
-    l4_port: int = nonebot.get_driver().config.l4_port
+    l4_port: list[str] = nonebot.get_driver().config.l4_port
 except:
-    l4_port: int = 20715
+    l4_port: list[str] = ['20715']
+l4_port = ast.literal_eval(l4_port)
 
 try:
-    l4_rcon: str = nonebot.get_driver().config.l4_rcon
+    l4_rcon: list[str] = nonebot.get_driver().config.l4_rcon
 except:
-    l4_rcon: str = '114514'
+    l4_rcon: list[str] = ['114514']
+l4_rcon = ast.literal_eval(l4_rcon)    
+    
 try:
-    l4_master: list = nonebot.get_driver().config.l4_master
+    l4_master: list[str] = nonebot.get_driver().config.l4_master
 except:
-    l4_master: list = ['114514']
+    l4_master: list[str] = ['114514']
+l4_master =ast.literal_eval(l4_master)    
+    
 try:
-    l4_proxies: str = {
+    l4_proxies: set = {
             'http://':nonebot.get_driver().config.l4_proxies
         }
 except:
     l4_proxies = ''
-# 文件路径
-vpk_path = "left4dead2/addons"
-cfg_server = Path(l4_file,'left4dead2/cfg/server.cfg')
-map_path = Path(l4_file,vpk_path)
-'''
+
+    '''
 地图路径
 '''
+vpk_path = "left4dead2/addons"
+map_path = Path(l4_file[CHECK_FILE],vpk_path)
+l4_file_one = l4_file[CHECK_FILE]
+l4_host_one = l4_host[CHECK_FILE]
+l4_port_one = int(l4_port[CHECK_FILE])
+l4_rcon_one = l4_rcon[CHECK_FILE]
+def load_config():
+    # 文件路径
+    global map_path,l4_file_one,l4_host_one,l4_port_one,l4_rcon_one
+    map_path = Path(l4_file[CHECK_FILE],vpk_path)
+    l4_file_one = l4_file[CHECK_FILE]
+    l4_host_one = l4_host[CHECK_FILE]
+    l4_port_one = int(l4_port[CHECK_FILE])
+    l4_rcon_one = l4_rcon[CHECK_FILE]
+
 
 PLAYERSDATA = Path() / "data/L4D2/image/players"
 """用户数据路径"""
@@ -105,3 +131,14 @@ tables_columns = {
 # 求生anne服务器
 anne_url = "https://server.trygek.com/"
 
+
+# 系统
+if platform.system() == 'Windows':
+    systems:str = 'win'
+elif platform.system() == 'Linux':
+    systems:str = 'linux'
+else:
+    systems:str = 'others'
+
+
+
